package com.afp.ordermanagement.model;

import lombok.Data;
import lombok.NoArgsConstructor;
import org.hibernate.validator.constraints.URL;
import org.springframework.data.annotation.Id;
import org.springframework.data.mongodb.core.index.Indexed;
import org.springframework.data.mongodb.core.mapping.Document;

import javax.validation.constraints.*;
import java.lang.reflect.Field;

import static java.util.Objects.isNull;

@Data
@NoArgsConstructor
@Document(collection = "managers")
public class Manager {
    @Id
    private String id;

    @Size(min = 1, max = 250)
    @NotNull()
    private String firstName, lastName;

    @Indexed(unique = true)
    @Email
    private String email;

    @Size(min = 21, max = 21)
    @NotNull()
    private String googleId;

    private String imageUrl;

    static public Manager combine(Manager target, Manager source) {
        try {
            for (Field field: Manager.class.getDeclaredFields()) {
                String fieldName = field.getName();
                Object sourceValue = field.get(source);
                if (!isNull(sourceValue) && !fieldName.equals("id"))
                    field.set(target, sourceValue);
            }
        } catch (Exception ignore) { }

        return target;
    }
}
